Welcome to Surprise’ documentation! — Surprise 1 documentation

# Welcome to Surprise’ documentation!

Surprise is an easy-to-use open source Python library for recommender systems.

If you’re new to Surprise, we invite you to take a look at the Getting Started guide, where you’ll find a series of tutorials illustrating all you can do with Surprise. For installation guidelines, please refer to the project page.

Any kind of feedback/criticism would be greatly appreciated (software design, documentation, improvement ideas, spelling mistakes, etc...). Please feel free to contribute and send pull requests (see GitHub page)!